@@ -12,11 +12,15 @@ class CancellableStreamThread:
         Feeds data from the gRPC stream into the callback
         until the cancel method is called.
         """
+        self.stream = None
+        self._canceled = False
 
         def target():
             while True:
                 try:
                     self.stream = create_stream()
+                    if self._canceled:
+                        return
                     for _ in self.stream:
                         if attribute is not None:
                             callback(getattr(_, attribute))
@@ -40,4 +44,6 @@ class CancellableStreamThread:
         t.start()
 
     def cancel(self):
-        self.stream.cancel()
+        self._canceled = True
+        if self.stream is not None:
+            self.stream.cancel()
