@@ -3,7 +3,8 @@ import sys
 import time
 import json
 from typing import Any, Callable, Dict, List, Optional, Union, Tuple
-from threading import Lock
+from threading import Lock, Thread
+from multiprocessing.pool import ThreadPool
 import grpc
 from formant.protos.agent.v1 import agent_pb2, agent_pb2_grpc
 from formant.protos.model.v1 import (
@@ -117,6 +118,7 @@ class Client:
         ignore_throttled=False,  # type: bool
         ignore_unavailable=False,  # type: bool
         local_dev=False,  # type: bool
+        thread_pool_size=10,  # type: int
     ):
         """
         __init__()
@@ -140,6 +142,7 @@ class Client:
         self.ignore_throttled = ignore_throttled
         self.ignore_unavailable = ignore_unavailable
         self._lock = Lock()
+        self._thread_pool = ThreadPool(processes=thread_pool_size)
         self._agent_url = agent_url  # type: str
         if local_dev == True:
             self._agent_url = os.getenv(
@@ -1064,7 +1067,9 @@ class Client:
         return outer_wrapper
 
     def custom_data_channel_binary_request_handler(
-        self, channel_name  # type: bytes
+        self,
+        channel_name,  # type: bytes
+        new_thread=False,  # type: bool
     ):
         # type : (...) -> Callable[Callable[agent_pb2.GetCustomDataChannelMessageStreamResponse, None], Callable[str, str]]: # noqa: E501
         """
@@ -1103,22 +1108,30 @@ class Client:
                             + str(e)
                         )
 
-                response_data = None
-                try:
-                    response = f(request_data)
-                    response_data = request_id + SUCCESS_RESPONSE_BYTE + response
-                except Exception as e:
-                    error_message = (
-                        "An error occurred while handling custom data channel request: "
-                        + e.__class__.__name__
-                        + ": "
-                        + str(e)
-                    )
-                    response_data = (
-                        request_id + ERROR_RESPONSE_BYTE + error_message.encode("utf-8")
-                    )
+                def call_and_respond():
+                    response_data = None
+                    try:
+                        response = f(request_data)
+                        response_data = request_id + SUCCESS_RESPONSE_BYTE + response
+                    except Exception as e:
+                        error_message = (
+                            "An error occurred while handling custom data channel request: "
+                            + e.__class__.__name__
+                            + ": "
+                            + str(e)
+                        )
+                        response_data = (
+                            request_id
+                            + ERROR_RESPONSE_BYTE
+                            + error_message.encode("utf-8")
+                        )
 
-                self.send_on_custom_data_channel(channel_name, response_data)
+                    self.send_on_custom_data_channel(channel_name, response_data)
+
+                if new_thread:
+                    self._thread_pool.apply_async(call_and_respond)
+                else:
+                    call_and_respond()
 
             # When the handler function is decorated,
             # we automatically register it as a callback
