@@ -21,6 +21,7 @@ class LocalizationManager:
         stream_name,  # type: str
         client,
         throttle_hz,  # type: float
+        rectify_odom_translation=False,  # type: bool
     ):
         self._client = client
         self._stream_name = stream_name  # type: str
@@ -40,6 +41,7 @@ class LocalizationManager:
         else:
             self._min_time_between_messages = 1.0 / throttle_hz
         self._tags = {}  # type: Dict
+        self._rectify_odom_translation = rectify_odom_translation
 
     def update_point_cloud(
         self,
@@ -110,6 +112,11 @@ class LocalizationManager:
             point_clouds = self._cached_point_clouds
             tags = self._tags
 
+        if self._rectify_odom_translation:
+            if map is not None and odometry is not None:
+                odometry.transform_to_world.x = -map.origin.translation.x
+                odometry.transform_to_world.y = -map.origin.translation.y
+
         localization = navigation_pb2.Localization(
             map=protected_to_proto(map),
             odometry=protected_to_proto(odometry),
