@@ -18,6 +18,19 @@ class Map:
             occupancy_grid_data=map.data,
         )
 
+    @classmethod
+    def from_costmap(cls, costmap):
+        nav2_msgs = get_ros_module("nav2_msgs.msg")
+        validate_type(costmap, nav2_msgs.Costmap)
+
+        return cls(
+            costmap.metadata.resolution,
+            costmap.metadata.size_x,
+            costmap.metadata.size_y,
+            origin=Transform.from_ros_pose(costmap.metadata.origin),
+            occupancy_grid_data=costmap.data
+        )
+
     def __init__(
         self,
         resolution,  # type: float
