@@ -14,6 +14,14 @@ class Odometry:
             twist=Twist.from_ros_twist_with_covariance(odometry.twist),
         )
 
+    @classmethod
+    def from_pose_with_covariance_stamped(cls, pose_msg):
+        geometry_msgs = get_ros_module("geometry_msgs.msg")
+        validate_type(pose_msg, geometry_msgs.PoseWithCovarianceStamped)
+        return cls(
+            pose=Transform.from_ros_pose(pose_msg.pose.pose)
+        )
+
     @classmethod
     def from_xy_direction(
         cls,
