@@ -12,7 +12,9 @@ class Path:
         return cls(poses=[Transform.from_ros_pose_stamped(pose) for pose in path.poses])
 
     def __init__(
-        self, poses: List[Transform] = [], transform_to_world: Transform = Transform()
+        self,
+        poses=[],  # type: List[Transform]
+        transform_to_world=Transform(),  # type: Transform
     ):
         self.poses = poses
         self.transform_to_world = transform_to_world
