@@ -3,11 +3,12 @@ from typing import Any
 
 python3 = True if sys.hexversion > 0x03000000 else False
 
+
 # TODO: Do not require pointcloud2 as intermidate step
 class PointCloud2:
     def __init__(
         self, height, width, is_dense, is_bigendian, fields, point_step, row_step
-    ) -> None:
+    ):
         self.height = height
         self.width = width
         self.is_dense = is_dense
