@@ -21,8 +21,8 @@ class Twist:
 
     def __init__(
         self,
-        linear: Vector3 = Vector3.identity(),
-        angular: Vector3 = Vector3.identity(),
+        linear=Vector3.identity(),  # type: Vector3
+        angular=Vector3.identity(),  # type: Vector3
     ):
         self.linear = linear
         self.angular = angular
