@@ -1,4 +1,4 @@
-from typing import Optional, List, Dict
+from typing import Optional, List, Dict  # noqa: F401
 import ntpath
 import os
 import requests
@@ -93,6 +93,21 @@ class Client:
 
         self._authenticate_request(call)
 
+    def get_organization(
+        self,
+    ):
+        def call(token):
+            headers = self._headers.copy()
+            headers["Authorization"] = "Bearer %s" % token
+            response = requests.get(
+                "%s/organizations/%s" % (self._admin_api, self._organization_id),
+                headers=headers,
+            )
+            response.raise_for_status()
+            return response.json()
+
+        return self._authenticate_request(call)
+
     def query(self, params):
         """Example query params (only start and end time are required):
         {
@@ -331,6 +346,55 @@ class Client:
 
         return self._authenticate_request(call)
 
+    def query_count(
+        self,
+        start,  # type: datetime.datetime
+        end,  # type: datetime.date
+        type,  # type: str
+    ):
+        def call(token):
+            params = {
+                "start": start.isoformat(),
+                "end": end.isoformat(),
+                "type": type,
+                "organizationId": self.get_organization_id(),
+            }
+            headers = self._headers.copy()
+            headers["Authorization"] = "Bearer %s" % token
+            response = requests.post(
+                "%s/counts/history" % self._query_api,
+                headers=headers,
+                json=params,
+            )
+            response.raise_for_status()
+            return response.json()
+
+        return self._authenticate_request(call)
+
+    def active_devices(
+        self,
+        start,  # type: datetime.datetime
+        end,  # type: datetime.datetime
+    ):
+        def call(token):
+            params = {
+                "start": start.isoformat(),
+                "end": end.isoformat(),
+                "type": "default",
+                "organizationId": self.get_organization_id(),
+            }
+            headers = self._headers.copy()
+            headers["Authorization"] = "Bearer %s" % token
+            response = requests.post(
+                "%s/counts/active-devices" % self._query_api,
+                headers=headers,
+                json=params,
+            )
+            response.raise_for_status()
+            return response.json()
+
+        return self._authenticate_request(call)
+
     def create_intervention_response(self, params):
         """
         Example intervention response params:
@@ -535,31 +599,68 @@ class Client:
         def call(token):
             headers = self._headers.copy()
             headers["Authorization"] = "Bearer %s" % token
-            response = requests.post(
-                "%s/events/query" % (self._admin_api),
+            result = {"items": []}
+            current_offset = 0
+            while True:
+                params["offset"] = current_offset
+                response = requests.post(
+                    "%s/events/query" % (self._admin_api),
+                    headers=headers,
+                    json=params,
+                )
+                response.raise_for_status()
+                parsed = response.json()
+                result["items"] += parsed["items"]
+                current_offset += len(parsed["items"])
+                if len(parsed["items"]) != 10000:
+                    break
+            return result
+
+        return self._authenticate_request(call)
+
+    def get_streams(self):
+        def call(token):
+            headers = self._headers.copy()
+            headers["Authorization"] = "Bearer %s" % token
+            response = requests.get(
+                "%s/streams/" % self._admin_api,
                 headers=headers,
-                json=params,
             )
             return response.json()
 
         return self._authenticate_request(call)
 
+    def delete_stream(self, stream_id):
+        def call(token):
+            headers = self._headers.copy()
+            headers["Authorization"] = "Bearer %s" % token
+            response = requests.delete(
+                "%s/streams/%s" % (self._admin_api, stream_id), headers=headers
+            )
+            response.raise_for_status()
+
+        return self._authenticate_request(call)
+
     def query_annotations(
         self,
-        start_time,  # type: datetime.datetime
+        start_time=None,  # type: Optional[datetime.datetime]
         device_ids=None,  # type: Optional[List[str]]
         tags=None,  # type: Optional[Dict[str,List[str]]]
         annotation_template_ids=None,  # type: Optional[List[str]]
         message=None,  # type:str
         keyword=None,  # type: str
-        end_time=datetime.datetime.now(tz=tzutc()),  # type: datetime.datetime
+        end_time=None,  # type: Optional[datetime.datetime]
         params=None,  # type: Dict
     ):
         params = params if params is not None else {}
 
         params["tags"] = tags
-        params["start"] = start_time.isoformat()
-        params["end"] = end_time.isoformat()
+        if start_time is not None:
+            params["start"] = start_time.isoformat()
+            if end_time is None:
+                end_time = datetime.datetime.now(tz=tzutc())
+        if end_time is not None:
+            params["end"] = end_time.isoformat()
         params["deviceIds"] = device_ids
         params["annotationTemplateIds"] = annotation_template_ids
         params["message"] = message
@@ -593,6 +694,7 @@ class Client:
         self._token_expiry = int(time.time()) + 3530
         self._token = result["authentication"]["accessToken"]
         self._organization_id = result["authentication"]["organizationId"]
+        self._headers["Org-ID"] = self._organization_id
         self._user_id = result["authentication"]["userId"]
 
     def _authenticate_request(self, call):
@@ -612,6 +714,78 @@ class Client:
                 sys.stderr.write("%s\n" % error.response.text)
                 raise error
 
+    def create_device(
+        self,
+        device_name,  # type: str
+        publicKey="",  # type: str
+        tags=None,  # type: Optional[Dict[str,List[str]]]
+        params=None,  # type: Dict
+    ):
+        params = params if params is not None else {}
+        params["tags"] = tags
+        params["name"] = device_name
+        params["publicKey"] = publicKey
+        params["enabled"] = True
+        params_stripped = _strip_none_values(params)
+
+        def call(token):
+            headers = self._headers.copy()
+            headers["Authorization"] = "Bearer %s" % token
+            response = requests.post(
+                "%s/devices" % (self._admin_api),
+                headers=headers,
+                json=params_stripped,
+            )
+            response.raise_for_status()
+            return response.json()
+
+        return self._authenticate_request(call)
+
+    def generate_provisioning_token(
+        self,
+        id,  # type: str
+        params=None,  # type: Dict
+    ):
+        params = params if params is not None else {}
+        params["id"] = id
+
+        def call(token):
+            headers = self._headers.copy()
+            headers["Authorization"] = "Bearer %s" % token
+            response = requests.post(
+                "%s/devices/%s/provisioning-token" % (self._admin_api, id),
+                headers=headers,
+                json=params,
+            )
+            response.raise_for_status()
+            return response.json()
+
+        return self._authenticate_request(call)
+
+    def provision_device(
+        self,
+        provisioningToken,  # type: str
+        publicKey,  # type: str
+        params=None,  # type: Dict
+    ):
+        params = params if params is not None else {}
+        params["provisioningToken"] = provisioningToken
+        params["publicKey"] = publicKey
+        params_stripped = _strip_none_values(params)
+
+        def call(token):
+            headers = self._headers.copy()
+            headers["Authorization"] = "Bearer %s" % token
+            response = requests.post(
+                "%s/devices/provision" % (self._admin_api),
+                headers=headers,
+                json=params_stripped,
+            )
+            response.raise_for_status()
+            return response.json()
+
+        return self._authenticate_request(call)
+
 
 def _strip_none_values(dict):
     return {k: v for k, v in dict.items() if v is not None}
